about summary refs log tree commit diff
path: root/elf/dl-fini.c
diff options
context:
space:
mode:
Diffstat (limited to 'elf/dl-fini.c')
-rw-r--r--elf/dl-fini.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/elf/dl-fini.c b/elf/dl-fini.c
index b3282089a9..a01b998ef0 100644
--- a/elf/dl-fini.c
+++ b/elf/dl-fini.c
@@ -98,9 +98,9 @@ _dl_fini (void)
 
 	    maps[i++] = l;
 
-	    /* Bump l_opencount of all objects so that they are not
-	       dlclose()ed from underneath us.  */
-	    ++l->l_opencount;
+	    /* Bump l_direct_opencount of all objects so that they are
+	       not dlclose()ed from underneath us.  */
+	    ++l->l_direct_opencount;
 	  }
       assert (cnt != LM_ID_BASE || i == nloaded);
       assert (cnt == LM_ID_BASE || i == nloaded || i == nloaded - 1);
@@ -237,7 +237,7 @@ _dl_fini (void)
 	    }
 
 	  /* Correct the previous increment.  */
-	  --l->l_opencount;
+	  --l->l_direct_opencount;
 	}
     }